@@ -71,6 +71,7 @@ darkstar = host "darkstar.kitenet.net" $ props
 	& Laptop.trimSSD
 	& Grub.cmdline_Linux_default "i915.enable_psr=1"
 	! Grub.cmdline_Linux_default "quiet"
+	& User.hasGroup (User "joey") (Group "dialout")
 
 	& JoeySites.dkimMilter
 	& JoeySites.postfixSaslPasswordClient
@@ -184,7 +185,7 @@ honeybee = host "honeybee.kitenet.net" $ props
 			`setSize` MegaBytes 16000
 		)
 	& JoeySites.cubieTruckOneWire
-	
+	& Systemd.persistentJournal
 	& Apt.installed ["firmware-atheros"]
 	& Apt.serviceInstalledRunning "ntp" -- no hardware clock
 	& bootstrappedFrom GitRepoOutsideChroot
@@ -192,17 +193,18 @@ honeybee = host "honeybee.kitenet.net" $ props
 		[ (SshEd25519, "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIIS/hDYq1MAxfOBf49htym3BOYlx4Gk9SDpiHjv7u6IC")
 		]
 
-	& JoeySites.homePower
+	& JoeySites.house
 		(User "joey")
 		hosts
-		(Context "homepower.joeyh.name")
+		(Context "house.joeyh.name")
 		(SshEd25519, "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIMAmVYddg/RgCbIj+cLcEiddeFXaYFnbEJ3uGj9G/EyV joey@honeybee")
 	& JoeySites.homeRouter
 	& JoeySites.homeNAS
 	& Apt.installed ["mtr-tiny", "iftop", "screen"]
 	& Postfix.satellite
 
-	& check (not <$> inChroot) (setupRevertableProperty autobuilder)
+	& check (not <$> hasContainerCapability Systemd.FilesystemContained) 
+		(setupRevertableProperty autobuilder)
 	-- In case compiler needs more than available ram
 	& Apt.serviceInstalledRunning "swapspace"
   where
@@ -259,7 +261,7 @@ kite = host "kite.kitenet.net" $ props
 		]
 		[ Borg.KeepDays 7
 		, Borg.KeepWeeks 4
-		, Borg.KeepMonths 6
+		, Borg.KeepMonths 3
 		]
 		`requires` Ssh.knownHost hosts "usw-s002.rsync.net" (User "root")
 		`requires` Ssh.userKeys (User "root")
@@ -395,8 +397,9 @@ pell = host "pell.branchable.com" $ props
 	& alias "dist-bugs.kitenet.net"
 	& alias "family.kitenet.net"
 
-	& osDebian (Stable "stretch") X86_64
+	& osDebian (Stable "buster") X86_32
 	& Apt.installed ["linux-image-686-pae"]
+	& Apt.stdSourcesList `onChange` Apt.upgrade
 	& Apt.unattendedUpgrades
 	& Branchable.server hosts
 	& Linode.serialGrub
@@ -407,7 +410,7 @@ keysafe = host "keysafe.joeyh.name" $ props
 	& ipv4 "139.59.17.168"
 	& Hostname.sane
 	& Hostname.mailname
-	& osDebian (Stable "stretch") X86_64
+	& osDebian (Stable "buster") X86_64
 	& Apt.stdSourcesList `onChange` Apt.upgrade
 	& Apt.unattendedUpgrades
 	& DigitalOcean.distroKernel
@@ -415,7 +418,8 @@ keysafe = host "keysafe.joeyh.name" $ props
 	& Apt.serviceInstalledRunning "swapspace"
 	& Cron.runPropellor (Cron.Times "30 * * * *")
 	& Apt.installed ["etckeeper", "sudo"]
-	& Apt.removed ["nfs-common", "exim4", "exim4-base", "exim4-daemon-light", "rsyslog", "acpid", "rpcbind", "at"]
+	& JoeySites.noExim
+	& Apt.removed ["nfs-common", "rsyslog", "acpid", "rpcbind", "at"]
 
 	& User.hasSomePassword (User "root")
 	& User.accountFor (User "joey")
@@ -466,7 +470,7 @@ keysafe = host "keysafe.joeyh.name" $ props
 -- Exhibit: kite's 90's website on port 1994.
 ancientKitenet :: Systemd.Container
 ancientKitenet = Systemd.debContainer "ancient-kitenet" $ props
-	& standardContainer (Stable "stretch")
+	& standardContainer (Stable "buster")
 	& alias hn
 	& Git.cloned (User "root") "git://kitenet-net.branchable.com/" "/var/www/html"
 		(Just "remotes/origin/old-kitenet.net")
@@ -480,7 +484,7 @@ ancientKitenet = Systemd.debContainer "ancient-kitenet" $ props
 
 oldusenetShellBox :: Systemd.Container
 oldusenetShellBox = Systemd.debContainer "oldusenet-shellbox" $ props
-	& standardContainer (Stable "stretch")
+	& standardContainer (Stable "buster")
 	& alias "shell.olduse.net"
 	& JoeySites.oldUseNetShellBox
 
@@ -488,6 +492,7 @@ oldusenetShellBox = Systemd.debContainer "oldusenet-shellbox" $ props
 -- and administrative sanity.
 openidProvider :: Systemd.Container
 openidProvider = Systemd.debContainer "openid-provider" $ props
+	-- simpleid is not in buster
 	& standardContainer (Stable "stretch")
 	& alias hn
 	& OpenId.providerFor [User "joey", User "liw"] hn (Just (Port 8086))
@@ -523,13 +528,14 @@ standardSystemUnhardened suite arch motd = propertyList "standard system" $ prop
 	& Apt.installed ["vim", "screen", "less"]
 	& Cron.runPropellor (Cron.Times "30 * * * *")
 	-- I use postfix, or no MTA.
-	& Apt.removed ["exim4", "exim4-daemon-light", "exim4-config", "exim4-base"]
-		`onChange` Apt.autoRemove
+	& JoeySites.noExim
 
 -- This is my standard container setup, Featuring automatic upgrades.
 standardContainer :: DebianSuite -> Property (HasInfo + Debian)
 standardContainer suite = propertyList "standard container" $ props
 	& osDebian suite X86_64
+	-- Do not want to run mail daemon inside a random container..
+	& JoeySites.noExim
 	& Apt.stdSourcesList `onChange` Apt.upgrade
 	& Apt.unattendedUpgrades
 	& Apt.cacheCleaned
