@@ -25,7 +25,6 @@ import qualified Propellor.Property.Network as Network
 import qualified Propellor.Property.Fail2Ban as Fail2Ban
 import qualified Propellor.Property.LetsEncrypt as LetsEncrypt
 import qualified Propellor.Property.Mount as Mount
-import Utility.FileMode
 import Utility.Split
 
 import Data.List
@@ -345,13 +344,7 @@ tmp = propertyList "tmp.joeyh.name" $ props
 		"tmp.joeyh.name"
 		"26fd6e38-1226-11e2-a75f-ff007033bdba"
 		[]
-	& pumpRss
-
--- Work around for expired ssl cert.
--- (Obsolete; need to revert this.)
-pumpRss :: Property DebianLike
-pumpRss = Cron.job "pump rss" (Cron.Times "15 * * * *") (User "joey") "/srv/web/tmp.joeyh.name/"
-	"wget https://pump2rss.com/feed/joeyh@identi.ca.atom -O pump.atom.new --no-check-certificate 2>/dev/null; sed 's/ & / /g' pump.atom.new > pump.atom"
+	& Cron.jobDropped "pump rss" (Cron.Times "15 * * * *")
 
 ircBouncer :: Property (HasInfo + DebianLike)
 ircBouncer = propertyList "IRC bouncer" $ props
@@ -761,10 +754,10 @@ legacyWebSites = propertyList "legacy web sites" $ props
 		, "# Redirect all to joeyh.name."
 		, "rewriterule (.*) http://joeyh.name$1 [r]"
 		]
-	& alias "homepower.joeyh.name"
-	& apacheSite "homepower.joeyh.name"
-		[ "DocumentRoot /srv/web/homepower.joeyh.name"
-		, "<Directory /srv/web/homepower.joeyh.name>"
+	& alias "house.joeyh.name"
+	& apacheSite "house.joeyh.name"
+		[ "DocumentRoot /srv/web/house.joeyh.name"
+		, "<Directory /srv/web/house.joeyh.name>"
 		, "  Options Indexes ExecCGI"
 		, "  AllowOverride None"
 		, Apache.allowAll
@@ -906,33 +899,34 @@ alarmClock oncalendar (User user) command = combineProperties "goodmorning timer
 	& "/etc/systemd/logind.conf" `ConfFile.containsIniSetting`
 		("Login", "LidSwitchIgnoreInhibited", "no")
 
-homePower :: IsContext c => User -> [Host] -> c -> (SshKeyType, Ssh.PubKeyText) -> Property (HasInfo + DebianLike)
-homePower user hosts ctx sshkey = propertyList "home power" $ props
+house :: IsContext c => User -> [Host] -> c -> (SshKeyType, Ssh.PubKeyText) -> Property (HasInfo + DebianLike)
+house user hosts ctx sshkey = propertyList "home automation" $ props
 	& Apache.installed
 	& Apt.installed ["python", "python-pymodbus", "rrdtool", "rsync"]
-	& File.ownerGroup "/var/www/html" user (userGroup user)
-	& Git.cloned user "https://git.joeyh.name/git/joey/homepower.git" d Nothing
+	& Git.cloned user "https://git.joeyh.name/git/joey/house.git" d Nothing
 	& Git.cloned user "https://git.joeyh.name/git/reactive-banana-automation.git" (d </> "reactive-banana-automation") Nothing
+	& websitesymlink
 	& build
 	& Systemd.enabled setupservicename
 		`requires` setupserviceinstalled
 		`onChange` Systemd.started setupservicename
-	& Systemd.enabled watchdogservicename
-		`requires` watchdogserviceinstalled
-		`onChange` Systemd.started watchdogservicename
 	& Systemd.enabled pollerservicename
 		`requires` pollerserviceinstalled
 		`onChange` Systemd.started pollerservicename
 	& Systemd.enabled controllerservicename
 		`requires` controllerserviceinstalled
 		`onChange` Systemd.started controllerservicename
+	& Systemd.enabled watchdogservicename
+		`requires` watchdogserviceinstalled
+		`onChange` Systemd.started watchdogservicename
+	& Apt.serviceInstalledRunning "watchdog"
 	& User.hasGroup user (Group "dialout")
 	& Group.exists (Group "gpio") Nothing
 	& User.hasGroup user (Group "gpio")
 	& Apt.installed ["i2c-tools"]
 	& User.hasGroup user (Group "i2c")
-	& "/etc/modules-load.d/homepower.conf" `File.hasContent` ["i2c-dev"]
-	& Cron.niceJob "homepower upload"
+	& "/etc/modules-load.d/house.conf" `File.hasContent` ["i2c-dev"]
+	& Cron.niceJob "house upload"
 		(Cron.Times "1 * * * *") user d rsynccommand
 		`requires` Ssh.userKeyAt (Just sshkeyfile) user ctx sshkey
 		`requires` File.ownerGroup (takeDirectory sshkeyfile)
@@ -941,7 +935,7 @@ homePower user hosts ctx sshkey = propertyList "home power" $ props
 		`requires` Ssh.knownHost hosts "kitenet.net" user
 	&  File.hasPrivContentExposed "/etc/darksky-forecast-url" anyContext
   where
-	d = "/var/www/html/homepower"
+	d = "/home/joey/house"
 	sshkeyfile = d </> ".ssh/key"
 	build = check (not <$> doesFileExist (d </> "controller")) $
 		userScriptProperty (User "joey")
@@ -962,11 +956,11 @@ homePower user hosts ctx sshkey = propertyList "home power" $ props
 			, "libghc-reactive-banana-dev"
 			, "libghc-hinotify-dev"
 			]
-	pollerservicename = "homepower"
+	pollerservicename = "house-poller"
 	pollerservicefile = "/etc/systemd/system/" ++ pollerservicename ++ ".service"
 	pollerserviceinstalled = pollerservicefile `File.hasContent`
 		[ "[Unit]"
-		, "Description=home power poller"
+		, "Description=house poller"
 		, ""
 		, "[Service]"
 		, "ExecStart=" ++ d ++ "/poller"
@@ -977,13 +971,13 @@ homePower user hosts ctx sshkey = propertyList "home power" $ props
 		, ""
 		, "[Install]"
 		, "WantedBy=multi-user.target"
-		, "WantedBy=homepower-controller.target"
+		, "WantedBy=house-controller.target"
 		]
-	controllerservicename = "homepower-controller"
+	controllerservicename = "house-controller"
 	controllerservicefile = "/etc/systemd/system/" ++ controllerservicename ++ ".service"
 	controllerserviceinstalled = controllerservicefile `File.hasContent`
 		[ "[Unit]"
-		, "Description=home power controller"
+		, "Description=house controller"
 		, ""
 		, "[Service]"
 		, "ExecStart=" ++ d ++ "/controller"
@@ -995,11 +989,11 @@ homePower user hosts ctx sshkey = propertyList "home power" $ props
 		, "[Install]"
 		, "WantedBy=multi-user.target"
 		]
-	watchdogservicename = "homepower-watchdog"
+	watchdogservicename = "house-watchdog"
 	watchdogservicefile = "/etc/systemd/system/" ++ watchdogservicename ++ ".service"
 	watchdogserviceinstalled = watchdogservicefile `File.hasContent`
 		[ "[Unit]"
-		, "Description=home power watchdog"
+		, "Description=house watchdog"
 		, ""
 		, "[Service]"
 		, "ExecStart=" ++ d ++ "/watchdog"
@@ -1011,11 +1005,11 @@ homePower user hosts ctx sshkey = propertyList "home power" $ props
 		, "[Install]"
 		, "WantedBy=multi-user.target"
 		]
-	setupservicename = "homepower-setup"
+	setupservicename = "house-setup"
 	setupservicefile = "/etc/systemd/system/" ++ setupservicename ++ ".service"
 	setupserviceinstalled = setupservicefile `File.hasContent`
 		[ "[Unit]"
-		, "Description=home power monitor setup"
+		, "Description=house setup"
 		, ""
 		, "[Service]"
 		, "ExecStart=" ++ d ++ "/setup"
@@ -1026,11 +1020,20 @@ homePower user hosts ctx sshkey = propertyList "home power" $ props
 		, ""
 		, "[Install]"
 		, "WantedBy=multi-user.target"
-		, "WantedBy=homepower.target"
+		, "WantedBy=house-poller.target"
+		, "WantedBy=house-controller.target"
+		, "WantedBy=house-watchdog.target"
 		]
 	-- Any changes to the rsync command will need my .authorized_keys
 	-- rsync server command to be updated too.
-	rsynccommand = "rsync -e 'ssh -i" ++ sshkeyfile ++ "' -avz rrds/ joey@kitenet.net:/srv/web/homepower.joeyh.name/rrds/"
+	rsynccommand = "rsync -e 'ssh -i" ++ sshkeyfile ++ "' -avz rrds/ joey@kitenet.net:/srv/web/house.joeyh.name/rrds/ >/dev/null 2>&1"
+
+	websitesymlink :: Property UnixLike
+	websitesymlink = check (not . isSymbolicLink <$> getSymbolicLinkStatus "/var/www/html")
+		(property "website symlink" $ makeChange $ do
+			removeDirectoryRecursive "/var/www/html"
+			createSymbolicLink d "/var/www/html"
+		)
 
 homerouterWifiInterfaceOld :: String
 homerouterWifiInterfaceOld = "wlx00c0ca82eb78" -- thinkpenguin wifi adapter
@@ -1070,7 +1073,7 @@ homeRouter = propertyList "home router" $ props
 		, "interface=" ++ homerouterWifiInterface
 		, "interface=eth0"
 		, "domain=kitenet.net"
-		-- lease time is short because the homepower
+		-- lease time is short because the house
 		-- controller wants to know when clients disconnect
 		, "dhcp-range=10.1.1.100,10.1.1.150,10m"
 		, "no-hosts"
@@ -1162,7 +1165,7 @@ laptopSoftware = Apt.installed
 	, "w3m", "sm", "weechat"
 	, "borgbackup", "wipe", "smartmontools", "libgfshare-bin"
 	, "units"
-	, "virtualbox", "qemu-kvm"
+	, "virtualbox", "virtualbox-guest-additions-iso", "qemu-kvm"
 	]
 	`requires` baseSoftware
 	`requires` devSoftware
@@ -1319,3 +1322,7 @@ rsyncNetBorgRepo d os = Borg.BorgRepoUsing os' ("2318@usw-s002.rsync.net:" ++ d)
   where
 	-- rsync.net has a newer borg here
 	os' = Borg.UsesEnvVar ("BORG_REMOTE_PATH", "borg1") : os
+
+noExim :: Property DebianLike
+noExim = Apt.removed ["exim4", "exim4-base", "exim4-daemon-light"]
+	`onChange` Apt.autoRemove
